@@ -16,6 +16,7 @@ from dvc.lock import LockError
 from dvc.repo import Repo as DVCRepo
 from git.repo import Repo as GITRepo
 
+from smartparams.utils.io import load_data, save_data
 from smartparams.utils.vocab import VOCABULARY
 
 PATTERNS = dict(
@@ -188,21 +189,76 @@ class SmartLab:
 
         path.with_suffix(path.suffix + '.dvc').unlink(missing_ok=True)
 
+    def metadata(
+        self,
+        /,
+        include_date: bool = True,
+        include_system: bool = True,
+        include_git: bool = True,
+        include_dependencies: bool = True,
+        save_to: Optional[Path] = None,
+        **kwargs: Any,
+    ) -> Dict[str, Any]:
+        """Returns most important information about platform and project versions.
+
+        Args:
+            include_date: Whether to include date and time.
+            include_system: Whether to include system info data.
+            include_git: Whether to include git branch and commit hash.
+            include_dependencies: Whether to include list of packages and versions.
+            save_to: Path to save metadata.
+
+        Returns:
+            Dictionary with metadata.
+
+        """
+        metadata = {
+            **(self._date_metadata() if include_date else {}),
+            **(self._system_metadata() if include_system else {}),
+            **(self._git_metadata() if include_git else {}),
+            **(self._dependencies_metadata() if include_dependencies else {}),
+            **kwargs,
+        }
+
+        if save_to:
+            metadata_history = load_data(save_to) if save_to.exists() else dict()
+            metadata_history[f'run{len(metadata_history) + 1:03d}'] = metadata
+            save_data(
+                data=metadata_history,
+                path=save_to,
+            )
+
+        return metadata
+
     @staticmethod
-    def metadata() -> Dict[str, Any]:
+    def _date_metadata() -> Dict[str, Any]:
         date = datetime.now()
-        path, *args = sys.argv
-        repo = GITRepo(path, search_parent_directories=True)
         return dict(
             date=date.strftime('%Y-%m-%d'),
             time=date.strftime('%H:%M:%S'),
+        )
+
+    @staticmethod
+    def _system_metadata() -> Dict[str, Any]:
+        return dict(
             user=os.getlogin(),
             host=platform.node(),
             os=platform.platform(),
             python=platform.python_version(),
-            args=args,
+            args=sys.argv[1:],
+        )
+
+    @staticmethod
+    def _git_metadata() -> Dict[str, Any]:
+        repo = GITRepo(sys.argv[0], search_parent_directories=True)
+        return dict(
             branch=repo.active_branch.name,
             commit=repo.active_branch.commit.hexsha if repo.active_branch.is_valid() else None,
+        )
+
+    @staticmethod
+    def _dependencies_metadata() -> Dict[str, Any]:
+        return dict(
             packages=[f'{package.key}=={package.version}' for package in pkg_resources.working_set],
         )
 
