@@ -12,7 +12,8 @@ _DEFAULT_FORMAT = 'yaml'
 
 @dataclass
 class Arguments:
-    path: Path
+    path: Optional[Path]
+    mode: Optional[str]
     dump: bool
     skip_defaults: bool
     merge_params: bool
@@ -56,11 +57,12 @@ def parse_arguments(parser: argparse.ArgumentParser) -> Arguments:
     if args.dump and args.format:
         parser.error("Cannot use --format with --dump.")
 
-    if args.mode:
-        args.path = args.path.with_suffix(f'.{args.mode}{args.path.suffix}')
+    if args.mode and not args.path:
+        parser.error("Cannot use --mode without --path.")
 
     return Arguments(
         path=args.path,
+        mode=args.mode,
         print=args.print,
         dump=args.dump,
         skip_defaults=args.skip_defaults,
