@@ -1,4 +1,4 @@
-from typing import Any
+from typing import Any, Type
 
 from smartparams.smart import Smart
 
@@ -21,11 +21,13 @@ class ClassComposition:
         vanilla_cls: Class,
         smart_cls: Smart[Class],
         smart: Smart,
+        class_type: Type[Class],
         unknown: Any,
     ) -> None:
         self.vanilla_cls = vanilla_cls
         self.smart_cls = smart_cls
         self.smart = smart
+        self.class_type = class_type
         self.unknown = unknown
 
 
@@ -46,6 +48,7 @@ class ClassCompositionChild(ClassComposition):
             smart_cls=smart_cls,
             smart=smart,
             unknown=unknown,
+            class_type=Class,
         )
         self.no_type = no_type
         self.args = args
